package Bad::BadClass;

sub long_method {
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
    print;
}

sub complex_method {
    my $case = "dog";
    if ( $case eq "1" ) {
    }
    elsif ( $case eq "2" ) {
        print "hello";
    }
    elsif ( $case eq "2" ) {
        print "hello";
    }
    elsif ( $case eq "2" ) {
        print "hello";
    }
    elsif ( $case eq "2" ) {
        print "hello";
    }
    elsif ( $case eq "2" ) {
        print "hello";
    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }
    elsif ( $case eq "2" ) {
        print "hello";

    }

}

1;
